@@ -5,7 +5,7 @@ Created By Murray(m18527) on 2019/9/4 16:48
 from copy import deepcopy
 from .backbone import Backbone, BackboneV1, BackboneV2
 from ..models import Teacher, Student, Class, Classroom, Subject, CourseTableManager, RestTable, News, Notice, Album, \
-    Video, Image, School, MeetingRoom, EduOrgUser
+    Video, Image, School, MeetingRoom, EduOrgUser, Campus
 from ..models import CourseTableManagerV1
 from ..models import RestTableV2, CourseTableManagerV2, SemesterV2
 from ..utils.constants import ERROR_PARAMS, SUCCESS, MSG
@@ -779,3 +779,63 @@ class DataClientV3(DataClient):
             return code, data
         else:
             return ERROR_PARAMS, "未查询到行政管理人员信息"
+
+    @staticmethod
+    def create_campus(campus):
+        """
+        create campus of class card server.
+        :param campus:  campus list or instance
+        :return: code, msg
+        """
+        is_multi, campus_map = True, {}
+        if not isinstance(campus, Campus) and not isinstance(campus, list):
+            logger.error("Error: No data or wrong student instance.")
+            return ERROR_PARAMS, "数据为空或格式不正确。"
+        if isinstance(campus, Campus):
+            campus = [campus]
+            is_multi = False
+        if campus and is_multi:
+            backbone = Backbone(school_id=None)
+            backbone.wrap_campus_map()
+            campus_map = backbone.campus_map
+
+        code_list, msg_list = [], []
+        for index, s in enumerate(campus):
+
+            if s.uid:
+                code, rlt = update_campus(s.uid, s.nirvana_data)
+            elif s.external_id in campus_map:
+                code, rlt = update_campus(campus_map[s.external_id], s.nirvana_data)
+            else:
+                code, rlt = create_campus(s.nirvana_data)
+            if code:
+                logger.error("Error, create campus fail, Detail: {}, Data: {}".format(rlt, s.sso_data))
+            code_list.append(code)
+            msg_list.append(rlt)
+            print(">>> Already create {}/{} campus".format(index + 1, len(campus)))
+
+        if is_multi:
+            return code_list, msg_list
+        return code_list[0], msg_list[0]
+
+    @staticmethod
+    def get_campus_info(params):
+        """
+        :param params: {"external_id":"xx", "name":"xx"}
+        :return:
+        """
+        code, data = get_campus(params)
+        if code:
+            logger.error("Error, query org_user info, Detail: {}".format(data))
+        return data
+
+    def delete_campus(self, params):
+        data = self.get_campus_info(params)
+        if len(data) > 1:
+            return ERROR_PARAMS, "查询校区信息不唯一"
+        elif len(data) == 1:
+            campus_id = data[0]['uid']
+            code, data = delete_campus(campus_id)
+            return code, data
+        else:
+            return ERROR_PARAMS, "未查询到校区信息"
