@@ -22,7 +22,8 @@ class Backbone(object):
         self.subject_map = {}  # num -> uid
         self.classroom_map = {}  # num -> uid
         self.teacher_map = {}  # number -> uid
-        self.edu_org_user = {} # number -> uid
+        self.edu_org_user = {}  # number -> uid
+        self.campus_map = {}    # external_id -> uid
         self.student_map = {}  # number -> uid
         self.class_map = {}  # name -> uid
         self.album_map = {}  # name-category -> uid
@@ -670,6 +671,13 @@ class Backbone(object):
         """
         self.edu_org_user_map = self.edtech_requester.wrap_map("get_edu_org_user_list", ["number"], "uuid")
 
+    def wrap_campus_map(self):
+        """
+        拉取行政管理人员列表，映射出uid
+        :return:
+        """
+        self.campus_map = self.nirvana_requester.wrap_map("get_campus", ["external_id"], "uid")
+
 
 class BackboneV1(Backbone):
     def __init__(self, school_id):
