@@ -1,5 +1,5 @@
 from ..models.base import BaseModel
-from ..utils.code import b64decode
+from ..utils.code import b64decode, b64encode
 
 
 class GenderSet(object):
@@ -38,7 +38,7 @@ class Teacher(BaseModel):
                 "name": self.name,
                 "number": self.number,
                 "phone": self.phone,
-                "password": b64decode(self.password),
+                "password": b64encode(self.password),
                 "school": self.school
                 }
         return data
@@ -75,7 +75,7 @@ class Student(BaseModel):
                 "name": self.name,
                 "number": self.number,
                 "phone": self.phone,
-                "password": b64decode(self.password),
+                "password": b64encode(self.password),
                 "classof": self.classof,
                 "graduateat": self.graduateat,
                 "section": self.class_id or self.section}
@@ -108,7 +108,7 @@ class EduOrgUser(BaseModel):
                 "name": self.name,
                 "number": self.number,
                 "phone": self.phone,
-                "password": b64decode(self.password),
+                "password": b64encode(self.password),
                 "job": self.job
                 }
         return data
