@@ -305,3 +305,25 @@ class NirvanaRequester(Requester):
                 "force": True}
         res = self._delete_method(route, data)
         return res
+
+    def get_campus(self, params={}):
+        route = "/api/edu/campus/"
+        res = self._get_method(route, params=params)
+        return res
+
+    def create_campus(self, data):
+        route = "/api/edu/campus/"
+        res = self._post_method(route, data)
+        return res
+
+    def update_campus(self, uid, data):
+        route = "/api/edu/campus/{}/".format(uid)
+        res = self._put_method(route, data)
+        return res
+
+    def delete_campus(self, uid):
+        route = "/api/edu/campus/{}/".format(uid)
+        data = {"soft": False,
+                "force": True}
+        res = self._delete_method(route, data)
+        return res
