@@ -334,4 +334,48 @@ def update_edu_org_user_req(org_user_id, data):
     data = resp.data.get('data', {}) if not code else resp.msg
     if code:
         logger.error("Error: Request: {}, Detail: {}".format(url, data))
-    return code, data
\ No newline at end of file
+    return code, data
+
+
+def create_campus(data):
+    """create campus of class card server"""
+    url = "{}/api/edu/campus/".format(class_card_server_url())
+    resp = do_post_request(url=url, json=data, token=class_card_server_token())
+    code = resp.code
+    data = resp.data.get('data', {}) if not code else resp.msg
+    if code:
+        logger.error("Error: Request: {}, Detail: {}".format(url, data))
+    return code, data
+
+
+def update_campus(campus_id, data):
+    """update campus of class card server"""
+    url = "{}/api/edu/campus/{}/".format(class_card_server_url(), campus_id)
+    resp = do_put_request(url=url, json=data, token=class_card_server_token())
+    code = resp.code
+    data = resp.data.get('data', {}) if not code else resp.msg
+    if code:
+        logger.error("Error: Request: {}, Detail: {}".format(url, data))
+    return code, data
+
+
+def get_campus(params):
+    """get campus info from class card server"""
+    url = "{}/api/edu/campus/".format(class_card_server_url())
+    resp = do_get_request(url=url, params=params, token=class_card_server_token(),)
+    code = resp.code
+    data = resp.data.get('data', {}) if not code else resp.msg
+    if code:
+        logger.error("Error: Request: {}, Detail: {}".format(url, data))
+    return code, data
+
+
+def delete_campus(campus_id):
+    """delete campus info from class card server"""
+    url = "{}/api/edu/campus/{}/".format(class_card_server_url(), campus_id)
+    resp = do_delete_request(url=url, token=class_card_server_token(),)
+    code = resp.code
+    data = resp.data.get('data', {}) if not code else resp.msg
+    if code:
+        logger.error("Error: Request: {}, Detail: {}".format(url, data))
+    return code, data
